import pymysql

from api_1104.common_.l_ini import Readini_
from api_1105 import log


class DB:
    def __init__(self):
        ini = Readini_()
        try:
            self.conn = pymysql.connect(
                host=ini.get_sql_msg('host'),
                port=int(ini.get_sql_msg('port')),
                user=ini.get_sql_msg('user'),
                password=ini.get_sql_msg('pwd'),
                database=ini.get_sql_msg('database'),
                charset="utf8")

            self.cursor = self.conn.cursor()
        except Exception as e:
            log.error(f"链接数据库时出错，请求检查ini配置文件，发生的错误类型为：{type(e)}, 错误的描述为：{e}")
            raise e

    def delete(self, sql_sentence):
        """执行删除的sql语句"""
        # 校验sql语句
        log.info(f"执行的方法为：delete，功能描述为：执行删除的sql语句，传入的参数为：{sql_sentence}")

        if isinstance(sql_sentence, str) and sql_sentence.strip().lower().startswith("delete"):
            try:
                # 执行删除的sql语句--使用游标对象execute方法
                self.cursor.execute(sql_sentence)
                # 使用链接对象提交
                self.conn.commit()
            except Exception as e:
                log.error(f"执行的方法为：delete，功能描述为：执行删除的sql语句，传入的参数为：{sql_sentence}, 错误类型为：{type(e)}, 错误的描述为：{e}")
                raise e
        else:
            log.error(f"执行的方法为：delete，功能描述为：执行删除的sql语句，传入的参数为：{sql_sentence}, 错误类型为：ValueError, 错误的描述为：sql语句错误")
            raise ValueError("sql语句错误")

    def select(self,sql_sentence):
        log.info(f"执行的方法为：select，功能描述为：执行查询的sql语句，传入的参数为：{sql_sentence}")

        if isinstance(sql_sentence, str) and sql_sentence.strip().lower().startswith("select"):
            try:
                self.cursor.execute(sql_sentence)
            except Exception as e:
                log.error(f"执行的方法为：select，功能描述为：执行查询的sql语句，传入的参数为：{sql_sentence}, 错误类型为：{type(e)}, 错误的描述为：{e}")
                raise e
            else:
                select_result = self.cursor.fetchall()

                if select_result:
                    return select_result[0][0]

        else:
            log.error(f"执行的方法为：select，功能描述为：执行查询的sql语句，传入的参数为：{sql_sentence}, 错误类型为：ValueError, 错误的描述为：sql语句错误")
            raise ValueError("sql语句异常")

# if __name__ == '__main__':
#     db = DB()
#     sql = """select ID_ from uc_demension where CODE_="M1111";"""
#     print(db.select(sql))