from pkgutil import get_data
from sys import modules

import openpyxl
from socks import method


from api_1105 import log
from api_1105.common_.l_basic_ini import Readbasicini
from api_1105.common_.l_json import read_json
from api_1105.common_.l_user_read import Readuserini


class ReadExcel:
    def __init__(self, user):
        ini = Readuserini(user)
        case_data_path = ini.get_file_path("case")
        expect_data_path = ini.get_file_path("expect")
        sql_data_path = ini.get_file_path("sql")
        self.case_data_dict = read_json(case_data_path)
        self.expect_data_dict = read_json(expect_data_path)
        self.sql_data_dict = read_json(sql_data_path)

        # 获取excel的文件路径和工作表的名称
        excel_path = ini.get_file_path("excel")
        table_name = ini.get_table_name('name')

        try:
            # 获取工作簿和工作表
            wb = openpyxl.load_workbook(excel_path)
            self.ws = wb[table_name]
        except Exception as e:
            log.error(
                f"获取excel的工作簿或工作表出错，excel的路径为：{excel_path}，工作表名称为：{table_name}，错误的类型为：{type(e)}, 错误的描述为：{e}")
            raise e

    def __get_cell_value(self, column: str, row: str) -> str:
        log.info(f"执行的方法为：__get_cell_value，功能描述为：获取指定单元格数据，传入的参数为：{column}列，{row}行")

        try:
            # 根据列号和行号获取指定单元格数据
            cell_value = self.ws[column + str(row)].value
        except Exception as e:
            log.error(f"执行的方法为：__get_cell_value，功能描述为：获取指定单元格数据，传入的参数为：{column}列，{row}行, 报错，错误类型为：{type(e)}, 错误的描述为：{e}")

            print(f"获取指定单元格数据出错，列号为：{column}, 行号为：{row}, 错误类型为：{type(e)}, 错误描述为：{e}")
            raise e
        else:
            # 判断单元格数据是否为None，如果是，返回None
            if cell_value is None:
                return None
            # 判断单元格数据去掉前后空格之后是否不为空的字符串，如果是，返回去掉前后空格的字符串，如果为空的字符串，返回None
            if cell_value.strip():  # 非空为True
                return cell_value.strip()

    def module_name(self, row):
        log.info(f"执行的方法为：module_name，功能描述为：根据行号，获取模块名称，传入的参数为：{row}行")

        return self.__get_cell_value("b", row)

    def api_name(self, row):
        log.info(f"执行的方法为：api_name，功能描述为：根据行号，获取接口名称，传入的参数为：{row}行")

        return self.__get_cell_value("c", row)

    def case_req_method(self, row):
        log.info(f"执行的方法为：req_method，功能描述为：根据行号，获取用例的请求方法，传入的参数为：{row}行")

        return self.__get_cell_value("f", row)

    def case_req_url(self, row):
        log.info(f"执行的方法为：req_url，功能描述为：根据行号，获取用例的请求url，传入的参数为：{row}行")

        path = self.__get_cell_value("g", row)

        if path:
            return Readbasicini().get_host("bpm") + path

    def case_req_mime(self, row):
        log.info(f"执行的方法为：req_mime，功能描述为：根据行号，获取用例的请求媒体类型，传入的参数为：{row}行")

        mime = self.__get_cell_value("h", row)

        if mime:
            return mime.lower()

    def case_data(self, row):
        log.info(f"执行的方法为：case_data，功能描述为：根据行号，获取用例数据，传入的参数为：{row}行")

        case_data_key = self.__get_cell_value("i", row)

        module_name = self.module_name(row)
        api_name = self.api_name(row)
        if case_data_key and module_name and api_name:
            return self.case_data_dict[module_name][api_name][case_data_key]

    def expect_data(self, row):
        """根据行号，获取期望数据"""
        log.info(f"执行的方法为：expect_data，功能描述为：根据行号，获取期望数据，传入的参数为：{row}行")

        expect_data_key = self.__get_cell_value("j", row)
        module_name = self.module_name(row)
        api_name = self.api_name(row)
        if expect_data_key and module_name and api_name:
            return self.expect_data_dict[module_name][api_name][expect_data_key]

    def sql_data(self, row):
        log.info(f"执行的方法为：sql_data，功能描述为：根据行号，获取sql语句，传入的参数为：{row}行")

        sql_data_key = self.__get_cell_value("l", row)
        module_name, api_name = self.module_name(row), self.api_name(row)

        if sql_data_key and module_name and api_name:
            return self.sql_data_dict[module_name][api_name][sql_data_key]

    def sql_type(self, row):
        log.info(f"执行的方法为：sql_type，功能描述为：根据行号，获取sql语句类型，传入的参数为：{row}行")
        type = self.__get_cell_value("k", row)

        if type:
            return type.lower()

    def update_key(self, row):
        log.info(f"执行的方法为：update_key，功能描述为：根据行号，获取用例的更新的key，传入的参数为：{row}行")

        return self.__get_cell_value("M", row)

    def get_data(self):
        list_data = []

        for row in range(2, self.ws.max_row + 1):
            method = self.case_req_method(row)
            url = self.case_req_url(row)
            mime = self.case_req_mime(row)
            case = self.case_data(row)
            expect = self.expect_data(row)
            sql = self.sql_data(row)
            sqltype = self.sql_type(row)
            updatekey = self.update_key(row)
            if method and url and expect:
                list_data.append([method, url, mime, case, expect, sql, sqltype, updatekey])

        else:
            return list_data


if __name__ == '__main__':
    excel = ReadExcel()
    print(excel.get_data())
